@@ -26,7 +26,9 @@
 #endif
 
 #ifdef __cplusplus
+/* *INDENT-OFF* */
 extern "C" {
+/* *INDENT-ON* */
 #endif
 
 #define UPSCLI_ERRBUF_LEN	256
@@ -154,13 +156,12 @@ int upscli_ssl(UPSCONN_t *ups);
 
 #define UPSCLI_CONN_TRYSSL	0x0001	/* try SSL, OK if not supported       */
 #define UPSCLI_CONN_REQSSL	0x0002	/* try SSL, fail if not supported     */
-#ifdef	HAVE_IPV6
 #define UPSCLI_CONN_INET	0x0004	/* IPv4 only */
 #define UPSCLI_CONN_INET6	0x0008	/* IPv6 only */
-#endif
 
 #ifdef __cplusplus
+/* *INDENT-OFF* */
 }
+/* *INDENT-ON* */
 #endif
-
 #endif	/* UPSCLIENT_H_SEEN */
