@@ -30,14 +30,25 @@
  * into submission
 */
 
-#define DRV_VERSION "0.5"
-#define SECS 2		/*wait time*/
-#define USEC 0		/*rest of wait time*/
-
 #include "main.h"
 #include "serial.h"
 #include "oneac.h"
 
+#define DRIVER_NAME	"Oneac EG/ON UPS driver"
+#define DRIVER_VERSION	"0.51"
+
+/* driver description structure */
+upsdrv_info_t upsdrv_info = {
+	DRIVER_NAME,
+	DRIVER_VERSION,
+	"Eric Lawson <elawson@inficad.com>",
+	DRV_EXPERIMENTAL,
+	{ NULL }
+};
+
+#define SECS 2		/*wait time*/
+#define USEC 0		/*rest of wait time*/
+
 void do_battery_test(void)
 {
 	char buffer[256];
@@ -101,7 +112,7 @@ void upsdrv_initinfo(void)
 	if(strncmp(buffer,MFGR, sizeof(MFGR)))
 		fatalx(EXIT_FAILURE, "Unable to connect to ONEAC UPS on %s\n",device_path);	
  
-	dstate_setinfo("ups.mfr", buffer);
+	dstate_setinfo("ups.mfr", "%s", buffer);
 	dstate_addcmd("test.battery.start");
 	dstate_addcmd("test.battery.stop");
 	dstate_addcmd("test.failure.start");
@@ -149,7 +160,7 @@ void upsdrv_initinfo(void)
 			buffer2[i] = '\0';
 		}
 
-		dstate_setinfo("ups.model", buffer2);
+		dstate_setinfo("ups.model", "%s", buffer2);
 		printf("Found %.10s UPS\n", buffer2);
 	}
 
@@ -195,7 +206,7 @@ void upsdrv_updateinfo(void)
 			IGNCHARS,SECS,USEC);
 	
 	upsdebugx (2,"upsrecv_updateinfo: upsrecv returned: %s\n",buffer);
-	if (ret_value == -1)
+	if (ret_value < 1)
 	{
 		ser_comm_fail("Oneac UPS Comm failure on port %s",device_path);
 		dstate_datastale();
@@ -291,13 +302,6 @@ void upsdrv_makevartable(void)
 		"Change battery test time from 2 minute default.");
 }
 
-void upsdrv_banner(void)
-{
-	printf("Network UPS Tools - Oneac EG/ON UPS driver %s (%s)\n\n", 
-		DRV_VERSION, UPS_VERSION);
-	experimental_driver = 1;	/*causes a warning to be printed*/
-}
-
 void upsdrv_initups(void)
 {
 	upsfd = ser_open(device_path);
