@@ -1,7 +1,7 @@
 /*
  * powercom.h - defines for the newpowercom.c driver
  *
- * $Id: powercom.h 2336 2010-02-11 20:16:43Z adkorte-guest $
+ * $Id: powercom.h 2627 2010-10-26 21:09:34Z adkorte-guest $
  *
  * Copyrights:
  * (C) 2002 Simon Rozman <simon@rozman.net>
@@ -41,7 +41,7 @@ struct type {
 	unsigned char num_of_bytes_from_ups;
 	
 	struct method_of_flow_control {
-	    char *name;
+	    const char *name;
 	    void (*setup_flow_control)(void);
 	} flowControl;
 	
