@@ -27,7 +27,6 @@
 
 #include "user.h"
 #include "user-data.h"
-#include "access.h"
 
 	ulist_t	*users = NULL;
 
@@ -36,77 +35,33 @@
 /* create a new user entry */
 static void user_add(const char *un)
 {
-	ulist_t	*tmp, *last;
+	ulist_t	*tmp, *last = NULL;
 
-	if (!un)
+	if (!un) {
 		return;
-	
-	tmp = last = users;
+	}
+
+	for (tmp = users; tmp != NULL; tmp = tmp->next) {
 
-	while (tmp) {
 		last = tmp;
 
 		if (!strcmp(tmp->username, un)) {
 			fprintf(stderr, "Ignoring duplicate user %s\n", un);
 			return;
 		}
-
-		tmp = tmp->next;
 	}
 
-	tmp = xmalloc(sizeof(ulist_t));
+	tmp = xcalloc(1, sizeof(*tmp));
 	tmp->username = xstrdup(un);
-	tmp->firstacl = NULL;
-	tmp->password = NULL;
-	tmp->firstcmd = NULL;
-	tmp->firstaction = NULL;
-	tmp->next = NULL;
-
-	if (last)
-		last->next = tmp;
-	else
-		users = tmp;	
-
-	/* remember who we're working on */
-	curr_user = tmp;
-}
-
-static acllist_t *addallow(acllist_t *base, const char *acl)
-{
-	acllist_t	*tmp, *last;
-
-	if (!acl)
-		return base;
-
-	tmp = last = base;
-
-	while (tmp) {
-		last = tmp;
-		tmp = tmp->next;
-	}
-
-	tmp = xmalloc(sizeof(acllist_t));
-	tmp->aclname = xstrdup(acl);
-	tmp->next = NULL;
 
 	if (last) {
 		last->next = tmp;
-		return base;
+	} else {
+		users = tmp;	
 	}
 
-	return tmp;
-}
-
-/* attach allowed hosts to user */
-static void user_add_allow(const char *host)
-{
-	if (!curr_user) {
-		upslogx(LOG_WARNING, "Ignoring allowfrom definition outside "
-			"user section");
-		return;
-	}
-
-	curr_user->firstacl = addallow(curr_user->firstacl, host);
+	/* remember who we're working on */
+	curr_user = tmp;
 }
 
 /* set password */
@@ -118,8 +73,9 @@ static void user_password(const char *pw)
 		return;
 	}
 
-	if (!pw)
+	if (!pw) {
 		return;
+	}
 
 	if (curr_user->password) {
 		fprintf(stderr, "Ignoring duplicate password for %s\n", 
@@ -133,7 +89,7 @@ static void user_password(const char *pw)
 /* attach allowed instcmds to user */
 static void user_add_instcmd(const char *cmd)
 {
-	instcmdlist_t	*tmp, *last;
+	instcmdlist_t	*tmp, *last = NULL;
 
 	if (!curr_user) {
 		upslogx(LOG_WARNING, "Ignoring instcmd definition outside "
@@ -141,50 +97,46 @@ static void user_add_instcmd(const char *cmd)
 		return;
 	}
 
-	if (!cmd)
+	if (!cmd) {
 		return;
+	}
 
-	tmp = curr_user->firstcmd;
-	last = NULL;
+	for (tmp = curr_user->firstcmd; tmp != NULL; tmp = tmp->next) {
 
-	while (tmp) {
 		last = tmp;
 
 		/* ignore duplicates */
-		if (!strcasecmp(tmp->cmd, cmd))
+		if (!strcasecmp(tmp->cmd, cmd)) {
 			return;
-
-		tmp = tmp->next;
+		}
 	}
 
-	tmp = xmalloc(sizeof(instcmdlist_t));
+	tmp = xcalloc(1, sizeof(*tmp));
 
 	tmp->cmd = xstrdup(cmd);
-	tmp->next = NULL;
 
-	if (last)
+	if (last) {
 		last->next = tmp;
-	else
+	} else {
 		curr_user->firstcmd = tmp;
+	}
 }
 
 static actionlist_t *addaction(actionlist_t *base, const char *action)
 {
-	actionlist_t	*tmp, *last;
+	actionlist_t	*tmp, *last = NULL;
 
-	if (!action)
+	if (!action) {
 		return base;
-
-	tmp = last = base;
-
-	while (tmp) {
-		last = tmp;
-		tmp = tmp->next;
 	}
 
-	tmp = xmalloc(sizeof(actionlist_t));
+	for (tmp = base; tmp != NULL; tmp = tmp->next) {
+
+		last = tmp;
+	}
+
+	tmp = xcalloc(1, sizeof(*tmp));
 	tmp->action = xstrdup(action);
-	tmp->next = NULL;
 
 	if (last) {
 		last->next = tmp;
@@ -206,164 +158,103 @@ static void user_add_action(const char *act)
 	curr_user->firstaction = addaction(curr_user->firstaction, act);
 }
 
-static void flushacl(acllist_t *first)
+static void flushcmd(instcmdlist_t *ptr)
 {
-	acllist_t	*ptr, *next;
-
-	ptr = first;
-
-	while (ptr) {
-		next = ptr->next;
-
-		free(ptr->aclname);
-		free(ptr);
-
-		ptr = next;
+	if (!ptr) {
+		return;
 	}
+
+	flushcmd(ptr->next);
+
+	free(ptr->cmd);
+	free(ptr);
 }
 
-static void flushcmd(instcmdlist_t *first)
+static void flushaction(actionlist_t *ptr)
 {
-	instcmdlist_t	*ptr, *next;
-
-	ptr = first;
-
-	while (ptr) {
-		next = ptr->next;
-
-		free(ptr->cmd);
-		free(ptr);
-
-		ptr = next;
+	if (!ptr) {
+		return;
 	}
+
+	flushaction(ptr->next);
+
+	free(ptr->action);
+	free(ptr);
 }
 
-static void flushaction(actionlist_t *first)
+static void flushuser(ulist_t *ptr)
 {
-	actionlist_t	*ptr, *next;
-
-	ptr = first;
-
-	while (ptr) {
-		next = ptr->next;
-
-		free(ptr->action);
-		free(ptr);
-
-		ptr = next;
+	if (!ptr) {
+		return;
 	}
+
+	flushuser(ptr->next);
+	flushcmd(ptr->firstcmd);
+	flushaction(ptr->firstaction);
+
+	free(ptr->username);
+	free(ptr->password);
+	free(ptr);
 }
 
 /* flush all user attributes - used during reload */
 void user_flush(void)
 {
-	ulist_t	*ptr, *next;
-
-	ptr = users;
-
-	while (ptr) {
-		next = ptr->next;
-
-		if (ptr->firstacl)
-			flushacl(ptr->firstacl);
-
-		if (ptr->firstcmd)
-			flushcmd(ptr->firstcmd);
-
-		if (ptr->firstaction)
-			flushaction(ptr->firstaction);
-
-		free(ptr->username);
-		free(ptr->password);
-		free(ptr);
-
-		ptr = next;
-	}
-
+	flushuser(users);
 	users = NULL;
-}	
-
-#ifndef	HAVE_IPV6
-static int user_matchacl(ulist_t *user, const struct sockaddr_in *addr)
-#else
-static int user_matchacl(ulist_t *user, const struct sockaddr_storage *addr)
-#endif
-{
-	acllist_t	*tmp;
-
-	tmp = user->firstacl;
-
-	/* no acls means no access (fail-safe) */
-	if (!tmp)
-		return 0;		/* good */
-
-	while (tmp) {
-		if (acl_check(tmp->aclname, addr) == 1)
-			return 1;	/* good */
-	
-		tmp = tmp->next;
-	}
-
-	return 0;	/* fail */
 }
 
 static int user_matchinstcmd(ulist_t *user, const char * cmd)
 {
-	instcmdlist_t	*tmp = user->firstcmd;
+	instcmdlist_t	*tmp;
 
-	/* no commands means no access (fail-safe) */
-	if (!tmp)
-		return 0;	/* fail */
+	for (tmp = user->firstcmd; tmp != NULL; tmp = tmp->next) {
 
-	while (tmp) {
-		if ((!strcasecmp(tmp->cmd, cmd)) || 
-			(!strcasecmp(tmp->cmd, "all")))
+		if (!strcasecmp(tmp->cmd, cmd)) {
 			return 1;	/* good */
-		tmp = tmp->next;
+		}
+
+		if (!strcasecmp(tmp->cmd, "all")) {
+			return 1;	/* good */
+		}
 	}
 
 	return 0;	/* fail */
 }
 
-#ifndef	HAVE_IPV6
-int user_checkinstcmd(const struct sockaddr_in *addr, 
-#else
-int user_checkinstcmd(const struct sockaddr_storage *addr, 
-#endif
-	const char *un, const char *pw, const char *cmd)
+int user_checkinstcmd(const char *un, const char *pw, const char *cmd)
 {
-	ulist_t	*tmp = users;
+	ulist_t	*tmp;
 
-	if ((!un) || (!pw) || (!cmd))
+	if ((!un) || (!pw) || (!cmd)) {
 		return 0;	/* failed */
+	}
 
-	while (tmp) {
+	for (tmp = users; tmp != NULL; tmp = tmp->next) {
 
 		/* let's be paranoid before we call strcmp */
 
 		if ((!tmp->username) || (!tmp->password)) {
-			tmp = tmp->next;
 			continue;
 		}
 
-		if (!strcmp(tmp->username, un)) {
-			if (!strcmp(tmp->password, pw)) {
-				if (!user_matchacl(tmp, addr))
-					return 0;		/* fail */
+		if (strcmp(tmp->username, un)) {
+			continue;
+		}
 
-				if (!user_matchinstcmd(tmp, cmd))
-					return 0;		/* fail */
-
-				/* passed all checks */
-				return 1;	/* good */
-			}
 
+		if (strcmp(tmp->password, pw)) {
 			/* password mismatch */
 			return 0;	/* fail */
 		}
 
-		tmp = tmp->next;
-	}		
+		if (!user_matchinstcmd(tmp, cmd)) {
+			return 0;		/* fail */
+		}
+
+		/* passed all checks */
+		return 1;	/* good */
+	}
 
 	/* username not found */
 	return 0;	/* fail */
@@ -371,66 +262,50 @@ int user_checkinstcmd(const struct sockaddr_storage *addr,
 
 static int user_matchaction(ulist_t *user, const char *action)
 {
-	actionlist_t	*tmp = user->firstaction;
+	actionlist_t	*tmp;
 
-	/* no actions means no access (fail-safe) */
-	if (!tmp)
-		return 0;	/* fail */
+	for (tmp = user->firstaction; tmp != NULL; tmp = tmp->next) {
 
-	while (tmp) {
-		if (!strcasecmp(tmp->action, action))
+		if (!strcasecmp(tmp->action, action)) {
 			return 1;	/* good */
-		tmp = tmp->next;
+		}
 	}
 
 	return 0;	/* fail */
 }
 
-#ifndef	HAVE_IPV6
-int user_checkaction(const struct sockaddr_in *addr, 
-#else
-int user_checkaction(const struct sockaddr_storage *addr, 
-#endif
-	const char *un, const char *pw, const char *action)
+int user_checkaction(const char *un, const char *pw, const char *action)
 {
-	ulist_t	*tmp = users;
+	ulist_t	*tmp;
 
 	if ((!un) || (!pw) || (!action))
 		return 0;	/* failed */
 
-	while (tmp) {
+	for (tmp = users; tmp != NULL; tmp = tmp->next) {
 
 		/* let's be paranoid before we call strcmp */
 
 		if ((!tmp->username) || (!tmp->password)) {
-			tmp = tmp->next;
 			continue;
 		}
 
-		if (!strcmp(tmp->username, un)) {
-			if (!strcmp(tmp->password, pw)) {
+		if (strcmp(tmp->username, un)) {
+			continue;
+		}
 
-				if (!user_matchacl(tmp, addr)) {
-					upsdebugx(2, "user_matchacl: failed");
-					return 0;		/* fail */
-				}
-
-				if (!user_matchaction(tmp, action)) {
-					upsdebugx(2, "user_matchaction: failed");
-					return 0;		/* fail */
-				}
-
-				/* passed all checks */
-				return 1;	/* good */
-			}
-
-			/* password mismatch */
+		if (strcmp(tmp->password, pw)) {
 			upsdebugx(2, "user_checkaction: password mismatch");
 			return 0;	/* fail */
 		}
 
-		tmp = tmp->next;
-	}		
+		if (!user_matchaction(tmp, action)) {
+			upsdebugx(2, "user_matchaction: failed");
+			return 0;	/* fail */
+		}
+
+		/* passed all checks */
+		return 1;	/* good */
+	}
 
 	/* username not found */
 	return 0;	/* fail */
@@ -475,7 +350,7 @@ static void parse_var(char *var, char *val)
 	}
 
 	if (!strcasecmp(var, "allowfrom")) {
-		user_add_allow(val);
+		upslogx(LOG_WARNING, "allowfrom in upsd.users is no longer used");
 		return;
 	}
 
@@ -494,28 +369,33 @@ static void parse_rest(char *var, char *fval, char **arg, int next, int left)
 	int	i;
 
 	/* no globals supported yet, so there's no sense in continuing */
-	if (!curr_user)
+	if (!curr_user) {
 		return;
+	}
 
 	parse_var(var, fval);
 
-	if (left == 0)
+	if (left == 0) {
 		return;
+	}
 
-	for (i = 0; i < left; i++)
+	for (i = 0; i < left; i++) {
 		parse_var(var, arg[next + i]);
+	}
 }
 
 static void user_parse_arg(int numargs, char **arg)
 {
 	char	*ep;
 
-	if ((numargs == 0) || (!arg))
+	if ((numargs == 0) || (!arg)) {
 		return;
+	}
 
 	/* ignore old file format */
-	if (!strcasecmp(arg[0], "user"))
+	if (!strcasecmp(arg[0], "user")) {
 		return;
+	}
 
 	/* handle 'foo=bar' (compressed form) */
 
@@ -534,21 +414,25 @@ static void user_parse_arg(int numargs, char **arg)
 
 	/* look for section headers - [username] */
 	if ((arg[0][0] == '[') && (arg[0][strlen(arg[0])-1] == ']')) {
+
 		arg[0][strlen(arg[0])-1] = '\0';
 		user_add(&arg[0][1]);
 
 		return;
 	}
 
-	if (numargs < 2)
+	if (numargs < 2) {
 		return;
+	}
 
-	if (!strcasecmp(arg[0], "upsmon"))
+	if (!strcasecmp(arg[0], "upsmon")) {
 		set_upsmon_type(arg[1]);
+	}
 
 	/* everything after here needs arg[1] and arg[2] */
-	if (numargs < 3)
+	if (numargs < 3) {
 		return;
+	}
 
 	/* handle 'foo = bar' (split form) */
 	if (!strcmp(arg[1], "=")) {
@@ -585,6 +469,7 @@ void user_load(void)
 	pconf_init(&ctx, upsd_user_err);
 
 	if (!pconf_file_begin(&ctx, fn)) {
+
 		pconf_finish(&ctx);
 
 		upslogx(LOG_WARNING, "%s", ctx.errmsg);
@@ -592,6 +477,7 @@ void user_load(void)
 	}
 
 	while (pconf_file_next(&ctx)) {
+
 		if (pconf_parse_error(&ctx)) {
 			upslogx(LOG_ERR, "Parse error: %s:%d: %s",
 				fn, ctx.linenum, ctx.errmsg);
