@@ -1,6 +1,6 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 #   Current Version : 1.0
-#   Copyright (C) 2008
+#   Copyright (C) 2008 - 2010
 #            Arnaud Quette <arnaud.quette@gmail.com>
 #            dloic (loic.dardant AT gmail DOT com)
 #
@@ -36,12 +36,12 @@ my $outputHotplug="../scripts/hotplug/libhid.usermap";
 # udev output file
 my $outputUdev="../scripts/udev/nut-usbups.rules.in";
 
-# DeviceKit-power output file
-my $outputDKp="../scripts/dkp/95-devkit-power-hid.rules";
-# tmp output, to allow generating the ENV{DKP_VENDOR} header list
-my $tmpOutputDKp;
+# UPower output file
+my $outputUPower="../scripts/upower/95-upower-hid.rules";
+# tmp output, to allow generating the ENV{UPOWER_VENDOR} header list
+my $tmpOutputUPower;
 # mfr header flag
-my $dkpMfrHeaderDone = 0;
+my $upowerMfrHeaderDone = 0;
 
 # array of products indexed by vendorID 
 my %vendor;
@@ -79,20 +79,20 @@ sub gen_usb_files
 	# Udev file header
 	open my $outUdev, ">$outputUdev" || die "error $outputUdev : $!";
 	print $outUdev '# This file is generated and installed by the Network UPS Tools package.'."\n\n";
-	print $outUdev 'ACTION!="add", GOTO="nut-usbups_rules_end"'."\n";
+	print $outUdev 'ACTION!="add|change", GOTO="nut-usbups_rules_end"'."\n";
 	print $outUdev 'SUBSYSTEM=="usb_device", GOTO="nut-usbups_rules_real"'."\n";
 	print $outUdev 'SUBSYSTEM=="usb", GOTO="nut-usbups_rules_real"'."\n";
-	print $outUdev 'BUS!="usb", GOTO="nut-usbups_rules_end"'."\n\n";
+	print $outUdev 'SUBSYSTEM!="usb", GOTO="nut-usbups_rules_end"'."\n\n";
 	print $outUdev 'LABEL="nut-usbups_rules_real"'."\n";
 
-	# DeviceKit-power file header
-	open my $outputDKp, ">$outputDKp" || die "error $outputDKp : $!";
-	print $outputDKp '##############################################################################################################'."\n";
-	print $outputDKp '# Uninterruptible Power Supplies with USB HID interfaces'."\n#\n";
-	print $outputDKp '# to keep up to date, monitor: http://svn.debian.org/wsvn/nut/trunk/scripts/dkp/95-devkit-power-hid.rules'."\n\n";
-	print $outputDKp '# only support USB, else ignore'."\n".'SUBSYSTEM!="usb", GOTO="dkp_hid_end"'."\n\n";
-	print $outputDKp '# if usbraw device, ignore'."\n".'KERNEL!="hiddev*", GOTO="dkp_hid_end"'."\n\n";
-	print $outputDKp '# if an interface, ignore'."\n".'ENV{DEVTYPE}=="usb_interface", GOTO="dkp_hid_end"'."\n\n";
+	# UPower file header
+	open my $outputUPower, ">$outputUPower" || die "error $outputUPower : $!";
+	print $outputUPower '##############################################################################################################'."\n";
+	print $outputUPower '# Uninterruptible Power Supplies with USB HID interfaces'."\n#\n";
+	print $outputUPower '# to keep up to date, monitor: http://svn.debian.org/wsvn/nut/trunk/scripts/upower/95-upower-hid.rules'."\n\n";
+	print $outputUPower '# only support USB, else ignore'."\n".'SUBSYSTEM!="usb", GOTO="up_hid_end"'."\n\n";
+	print $outputUPower '# if usbraw device, ignore'."\n".'KERNEL!="hiddev*", GOTO="up_hid_end"'."\n\n";
+	print $outputUPower '# if an interface, ignore'."\n".'ENV{DEVTYPE}=="usb_interface", GOTO="up_hid_end"'."\n\n";
 
 	# generate the file in alphabetical order (first for VendorID, then for ProductID)
 	foreach my $vendorId (sort { lc $a cmp lc $b } keys  %vendorName)
@@ -113,8 +113,8 @@ sub gen_usb_files
 			print $outUdev "\n# ".$vendorName{$vendorId}."\n";
 		}
 
-		# DeviceKit-power vendor header flag
-		$dkpMfrHeaderDone = 0;
+		# UPower vendor header flag
+		$upowerMfrHeaderDone = 0;
 
 		foreach my $productId (sort { lc $a cmp lc $b } keys %{$vendor{$vendorId}})
 		{
@@ -138,21 +138,21 @@ sub gen_usb_files
 			print $outUdev "\", ATTR{idProduct}==\"".removeHexPrefix($productId)."\",";
 			print $outUdev ' MODE="664", GROUP="@RUN_AS_GROUP@"'."\n";
 			
-			# DeviceKit-power device entry (only for USB/HID devices!)
+			# UPower device entry (only for USB/HID devices!)
 			if ($vendor{$vendorId}{$productId}{"driver"} eq "usbhid-ups")
 			{
-				if ($dkpMfrHeaderDone == 0)
+				if ($upowerMfrHeaderDone == 0)
 				{
-					# DeviceKit-power vendor header
+					# UPower vendor header
 					if ($vendorName{$vendorId}) {
-						$tmpOutputDKp = $tmpOutputDKp."\n# ".$vendorName{$vendorId}."\n";
+						$tmpOutputUPower = $tmpOutputUPower."\n# ".$vendorName{$vendorId}."\n";
 					}
-					print $outputDKp "ATTRS{idVendor}==\"".removeHexPrefix($vendorId)."\", ENV{DKP_VENDOR}=\"".$vendorName{$vendorId}."\"\n";
-					$dkpMfrHeaderDone = 1;
+					print $outputUPower "ATTRS{idVendor}==\"".removeHexPrefix($vendorId)."\", ENV{UPOWER_VENDOR}=\"".$vendorName{$vendorId}."\"\n";
+					$upowerMfrHeaderDone = 1;
 				}
-				$tmpOutputDKp = $tmpOutputDKp."ATTRS{idVendor}==\"".removeHexPrefix($vendorId);
-				$tmpOutputDKp = $tmpOutputDKp."\", ATTRS{idProduct}==\"".removeHexPrefix($productId)."\",";
-				$tmpOutputDKp = $tmpOutputDKp.' ENV{DKP_BATTERY_TYPE}="ups"'."\n";
+				$tmpOutputUPower = $tmpOutputUPower."ATTRS{idVendor}==\"".removeHexPrefix($vendorId);
+				$tmpOutputUPower = $tmpOutputUPower."\", ATTRS{idProduct}==\"".removeHexPrefix($productId)."\",";
+				$tmpOutputUPower = $tmpOutputUPower.' ENV{UPOWER_BATTERY_TYPE}="ups"'."\n";
 			}
 		}
 		# HAL vendor footer
@@ -166,11 +166,11 @@ sub gen_usb_files
 	# Udev footer
 	print $outUdev "\n".'LABEL="nut-usbups_rules_end"'."\n";
 
-	# DeviceKit-power...
+	# UPower...
 	# ...flush device table
-	print $outputDKp $tmpOutputDKp;
+	print $outputUPower $tmpOutputUPower;
 	# ...and print footer
-	print $outputDKp "\n".'LABEL="dkp_hid_end"'."\n";
+	print $outputUPower "\n".'LABEL="up_hid_end"'."\n";
 }
 
 sub find_usbdevs
@@ -244,9 +244,6 @@ sub find_usbdevs
 			elsif ($nameFile eq "tripplite_usb.c") {
 				$driver="tripplite_usb";
 			}
-			elsif ($nameFile eq "megatec_usb.c") {
-				$driver="megatec_usb";
-			}
 			elsif ($nameFile eq "blazer_usb.c") {
 				$driver="blazer_usb";
 			}
